==> aws-android-sdk-iot-2.15.0-sources.jar: com/amazonaws/services/iot/model/transform/UpdateSecurityProfileRequestMarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for UpdateSecurityProfileRequest
 */
public class UpdateSecurityProfileRequestMarshaller implements
        Marshaller<Request<UpdateSecurityProfileRequest>, UpdateSecurityProfileRequest> {

    public Request<UpdateSecurityProfileRequest> marshall(
            UpdateSecurityProfileRequest updateSecurityProfileRequest) {
        if (updateSecurityProfileRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(UpdateSecurityProfileRequest)");
        }

        Request<UpdateSecurityProfileRequest> request = new DefaultRequest<UpdateSecurityProfileRequest>(
                updateSecurityProfileRequest, "AWSIot");
        request.setHttpMethod(HttpMethodName.PATCH);

        String uriResourcePath = "/security-profiles/{securityProfileName}";
        uriResourcePath = uriResourcePath.replace(
                "{securityProfileName}",
                (updateSecurityProfileRequest.getSecurityProfileName() == null) ? "" : StringUtils
                        .fromString(updateSecurityProfileRequest.getSecurityProfileName()));
        if (updateSecurityProfileRequest.getExpectedVersion() != null) {
            request.addParameter("expectedVersion",
                    StringUtils.fromLong(updateSecurityProfileRequest.getExpectedVersion()));
        }
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (updateSecurityProfileRequest.getSecurityProfileDescription() != null) {
                String securityProfileDescription = updateSecurityProfileRequest
                        .getSecurityProfileDescription();
                jsonWriter.name("securityProfileDescription");
                jsonWriter.value(securityProfileDescription);
            }
            if (updateSecurityProfileRequest.getBehaviors() != null) {
                java.util.List<Behavior> behaviors = updateSecurityProfileRequest.getBehaviors();
                jsonWriter.name("behaviors");
                jsonWriter.beginArray();
                for (Behavior behaviorsItem : behaviors) {
                    if (behaviorsItem != null) {
                        BehaviorJsonMarshaller.getInstance().marshall(behaviorsItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }
            if (updateSecurityProfileRequest.getAlertTargets() != null) {
                java.util.Map<String, AlertTarget> alertTargets = updateSecurityProfileRequest
                        .getAlertTargets();
                jsonWriter.name("alertTargets");
                jsonWriter.beginObject();
                for (java.util.Map.Entry<String, AlertTarget> alertTargetsEntry : alertTargets
                        .entrySet()) {
                    AlertTarget alertTargetsValue = alertTargetsEntry.getValue();
                    if (alertTargetsValue != null) {
                        jsonWriter.name(alertTargetsEntry.getKey());
                        AlertTargetJsonMarshaller.getInstance().marshall(alertTargetsValue,
                                jsonWriter);
                    }
                }
                jsonWriter.endObject();
            }
            if (updateSecurityProfileRequest.getAdditionalMetricsToRetain() != null) {
                java.util.List<String> additionalMetricsToRetain = updateSecurityProfileRequest
                        .getAdditionalMetricsToRetain();
                jsonWriter.name("additionalMetricsToRetain");
                jsonWriter.beginArray();
                for (String additionalMetricsToRetainItem : additionalMetricsToRetain) {
                    if (additionalMetricsToRetainItem != null) {
                        jsonWriter.value(additionalMetricsToRetainItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (updateSecurityProfileRequest.getDeleteBehaviors() != null) {
                Boolean deleteBehaviors = updateSecurityProfileRequest.getDeleteBehaviors();
                jsonWriter.name("deleteBehaviors");
                jsonWriter.value(deleteBehaviors);
            }
            if (updateSecurityProfileRequest.getDeleteAlertTargets() != null) {
                Boolean deleteAlertTargets = updateSecurityProfileRequest.getDeleteAlertTargets();
                jsonWriter.name("deleteAlertTargets");
                jsonWriter.value(deleteAlertTargets);
            }
            if (updateSecurityProfileRequest.getDeleteAdditionalMetricsToRetain() != null) {
                Boolean deleteAdditionalMetricsToRetain = updateSecurityProfileRequest
                        .getDeleteAdditionalMetricsToRetain();
                jsonWriter.name("deleteAdditionalMetricsToRetain");
                jsonWriter.value(deleteAdditionalMetricsToRetain);
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.0");
        }

        return request;
    }
}

==> aws-android-sdk-iot-2.22.6-sources.jar: com/amazonaws/services/iot/model/transform/UpdateSecurityProfileRequestMarshaller.java <==
/*
 * Copyright 2010-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import android.text.TextUtils;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for UpdateSecurityProfileRequest
 */
public class UpdateSecurityProfileRequestMarshaller implements
        Marshaller<Request<UpdateSecurityProfileRequest>, UpdateSecurityProfileRequest> {

    public Request<UpdateSecurityProfileRequest> marshall(
            UpdateSecurityProfileRequest updateSecurityProfileRequest) {
        if (updateSecurityProfileRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(UpdateSecurityProfileRequest)");
        }

        Request<UpdateSecurityProfileRequest> request = new DefaultRequest<UpdateSecurityProfileRequest>(
                updateSecurityProfileRequest, "AWSIot");
        request.setHttpMethod(HttpMethodName.PATCH);

        String uriResourcePath = "/security-profiles/{securityProfileName}";
        uriResourcePath = uriResourcePath.replace(
                "{securityProfileName}",
                (updateSecurityProfileRequest.getSecurityProfileName() == null) ? "" : StringUtils
                        .fromString(updateSecurityProfileRequest.getSecurityProfileName()));
        if (updateSecurityProfileRequest.getExpectedVersion() != null) {
            request.addParameter("expectedVersion",
                    StringUtils.fromLong(updateSecurityProfileRequest.getExpectedVersion()));
        }
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (updateSecurityProfileRequest.getSecurityProfileDescription() != null) {
                String securityProfileDescription = updateSecurityProfileRequest
                        .getSecurityProfileDescription();
                jsonWriter.name("securityProfileDescription");
                jsonWriter.value(securityProfileDescription);
            }
            if (updateSecurityProfileRequest.getBehaviors() != null) {
                java.util.List<Behavior> behaviors = updateSecurityProfileRequest.getBehaviors();
                jsonWriter.name("behaviors");
                jsonWriter.beginArray();
                for (Behavior behaviorsItem : behaviors) {
                    if (behaviorsItem != null) {
                        BehaviorJsonMarshaller.getInstance().marshall(behaviorsItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }
            if (updateSecurityProfileRequest.getAlertTargets() != null) {
                java.util.Map<String, AlertTarget> alertTargets = updateSecurityProfileRequest
                        .getAlertTargets();
                jsonWriter.name("alertTargets");
                jsonWriter.beginObject();
                for (java.util.Map.Entry<String, AlertTarget> alertTargetsEntry : alertTargets
                        .entrySet()) {
                    AlertTarget alertTargetsValue = alertTargetsEntry.getValue();
                    if (alertTargetsValue != null) {
                        jsonWriter.name(alertTargetsEntry.getKey());
                        AlertTargetJsonMarshaller.getInstance().marshall(alertTargetsValue,
                                jsonWriter);
                    }
                }
                jsonWriter.endObject();
            }
            if (updateSecurityProfileRequest.getAdditionalMetricsToRetain() != null) {
                java.util.List<String> additionalMetricsToRetain = updateSecurityProfileRequest
                        .getAdditionalMetricsToRetain();
                jsonWriter.name("additionalMetricsToRetain");
                jsonWriter.beginArray();
                for (String additionalMetricsToRetainItem : additionalMetricsToRetain) {
                    if (additionalMetricsToRetainItem != null) {
                        jsonWriter.value(additionalMetricsToRetainItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (updateSecurityProfileRequest.getAdditionalMetricsToRetainV2() != null) {
                java.util.List<MetricToRetain> additionalMetricsToRetainV2 = updateSecurityProfileRequest
                        .getAdditionalMetricsToRetainV2();
                jsonWriter.name("additionalMetricsToRetainV2");
                jsonWriter.beginArray();
                for (MetricToRetain additionalMetricsToRetainV2Item : additionalMetricsToRetainV2) {
                    if (additionalMetricsToRetainV2Item != null) {
                        MetricToRetainJsonMarshaller.getInstance().marshall(
                                additionalMetricsToRetainV2Item, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }
            if (updateSecurityProfileRequest.getDeleteBehaviors() != null) {
                Boolean deleteBehaviors = updateSecurityProfileRequest.getDeleteBehaviors();
                jsonWriter.name("deleteBehaviors");
                jsonWriter.value(deleteBehaviors);
            }
            if (updateSecurityProfileRequest.getDeleteAlertTargets() != null) {
                Boolean deleteAlertTargets = updateSecurityProfileRequest.getDeleteAlertTargets();
                jsonWriter.name("deleteAlertTargets");
                jsonWriter.value(deleteAlertTargets);
            }
            if (updateSecurityProfileRequest.getDeleteAdditionalMetricsToRetain() != null) {
                Boolean deleteAdditionalMetricsToRetain = updateSecurityProfileRequest
                        .getDeleteAdditionalMetricsToRetain();
                jsonWriter.name("deleteAdditionalMetricsToRetain");
                jsonWriter.value(deleteAdditionalMetricsToRetain);
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.0");
        }

        return request;
    }
}
